# CallLLM

Asynchronous, concurrent requests to the LLM REST API, that respect its's rate limits, using [gevent](http://www.gevent.org/) and [requests](http://docs.python-requests.org/).

See example.py for a working example.

## Installation
Simply:

    $ pip install callllm

